Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterControllerServiceServer(s grpc.ServiceRegistrar, srv ControllerServiceServer)
- type ControllerServiceClient
- type ControllerServiceServer
- type ControllerService_ReceiveMessageClient
- type ControllerService_ReceiveMessageServer
- type ControllerService_RegisterDeviceClient
- type ControllerService_RegisterDeviceServer
- type DeleteWebhookRequest
- func (*DeleteWebhookRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteWebhookRequest) GetJid() string
- func (*DeleteWebhookRequest) ProtoMessage()
- func (x *DeleteWebhookRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteWebhookRequest) Reset()
- func (x *DeleteWebhookRequest) String() string
- type Empty
- type EventMessage
- func (*EventMessage) Descriptor() ([]byte, []int)deprecated
- func (x *EventMessage) GetFrom() string
- func (x *EventMessage) GetJid() string
- func (x *EventMessage) GetMessage() string
- func (*EventMessage) ProtoMessage()
- func (x *EventMessage) ProtoReflect() protoreflect.Message
- func (x *EventMessage) Reset()
- func (x *EventMessage) String() string
- type GetWebhookRequest
- type GetWebhookResponse
- func (*GetWebhookResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetWebhookResponse) GetTimestamp() int64
- func (x *GetWebhookResponse) GetUrl() string
- func (*GetWebhookResponse) ProtoMessage()
- func (x *GetWebhookResponse) ProtoReflect() protoreflect.Message
- func (x *GetWebhookResponse) Reset()
- func (x *GetWebhookResponse) String() string
- type RegisterDeviceRequest
- func (*RegisterDeviceRequest) Descriptor() ([]byte, []int)deprecated
- func (x *RegisterDeviceRequest) GetPhone() string
- func (x *RegisterDeviceRequest) GetPushNotification() bool
- func (*RegisterDeviceRequest) ProtoMessage()
- func (x *RegisterDeviceRequest) ProtoReflect() protoreflect.Message
- func (x *RegisterDeviceRequest) Reset()
- func (x *RegisterDeviceRequest) String() string
- type RegisterDeviceResponse
- func (*RegisterDeviceResponse) Descriptor() ([]byte, []int)deprecated
- func (x *RegisterDeviceResponse) GetJid() string
- func (x *RegisterDeviceResponse) GetLoggedIn() bool
- func (x *RegisterDeviceResponse) GetPairCode() string
- func (x *RegisterDeviceResponse) GetQr() string
- func (*RegisterDeviceResponse) ProtoMessage()
- func (x *RegisterDeviceResponse) ProtoReflect() protoreflect.Message
- func (x *RegisterDeviceResponse) Reset()
- func (x *RegisterDeviceResponse) String() string
- type SaveWebhookRequest
- func (*SaveWebhookRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SaveWebhookRequest) GetJid() string
- func (x *SaveWebhookRequest) GetUrl() string
- func (*SaveWebhookRequest) ProtoMessage()
- func (x *SaveWebhookRequest) ProtoReflect() protoreflect.Message
- func (x *SaveWebhookRequest) Reset()
- func (x *SaveWebhookRequest) String() string
- type SendImageMessageRequest
- func (*SendImageMessageRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SendImageMessageRequest) GetCaption() string
- func (x *SendImageMessageRequest) GetImage() []byte
- func (x *SendImageMessageRequest) GetJid() string
- func (x *SendImageMessageRequest) GetPhone() string
- func (*SendImageMessageRequest) ProtoMessage()
- func (x *SendImageMessageRequest) ProtoReflect() protoreflect.Message
- func (x *SendImageMessageRequest) Reset()
- func (x *SendImageMessageRequest) String() string
- type SendImageMessageResponse
- type SendMessageRequest
- func (*SendMessageRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SendMessageRequest) GetBody() string
- func (x *SendMessageRequest) GetJid() string
- func (x *SendMessageRequest) GetPhone() string
- func (*SendMessageRequest) ProtoMessage()
- func (x *SendMessageRequest) ProtoReflect() protoreflect.Message
- func (x *SendMessageRequest) Reset()
- func (x *SendMessageRequest) String() string
- type StatusRequest
- type StatusResponse
- type StatusResponse_Status
- func (StatusResponse_Status) Descriptor() protoreflect.EnumDescriptor
- func (x StatusResponse_Status) Enum() *StatusResponse_Status
- func (StatusResponse_Status) EnumDescriptor() ([]byte, []int)deprecated
- func (x StatusResponse_Status) Number() protoreflect.EnumNumber
- func (x StatusResponse_Status) String() string
- func (StatusResponse_Status) Type() protoreflect.EnumType
- type UnimplementedControllerServiceServer
- func (UnimplementedControllerServiceServer) DeleteWebhook(context.Context, *DeleteWebhookRequest) (*Empty, error)
- func (UnimplementedControllerServiceServer) GetWebhook(context.Context, *GetWebhookRequest) (*GetWebhookResponse, error)
- func (UnimplementedControllerServiceServer) ReceiveMessage(*Empty, grpc.ServerStreamingServer[EventMessage]) error
- func (UnimplementedControllerServiceServer) RegisterDevice(*RegisterDeviceRequest, grpc.ServerStreamingServer[RegisterDeviceResponse]) error
- func (UnimplementedControllerServiceServer) SaveWebhook(context.Context, *SaveWebhookRequest) (*Empty, error)
- func (UnimplementedControllerServiceServer) SendImageMessage(context.Context, *SendImageMessageRequest) (*SendImageMessageResponse, error)
- func (UnimplementedControllerServiceServer) SendMessage(context.Context, *SendMessageRequest) (*Empty, error)
- func (UnimplementedControllerServiceServer) Status(context.Context, *StatusRequest) (*StatusResponse, error)
- type UnsafeControllerServiceServer
Constants ¶
const ( ControllerService_Status_FullMethodName = "/ControllerService/Status" ControllerService_RegisterDevice_FullMethodName = "/ControllerService/RegisterDevice" ControllerService_SendMessage_FullMethodName = "/ControllerService/SendMessage" ControllerService_SendImageMessage_FullMethodName = "/ControllerService/SendImageMessage" ControllerService_ReceiveMessage_FullMethodName = "/ControllerService/ReceiveMessage" ControllerService_GetWebhook_FullMethodName = "/ControllerService/GetWebhook" ControllerService_SaveWebhook_FullMethodName = "/ControllerService/SaveWebhook" ControllerService_DeleteWebhook_FullMethodName = "/ControllerService/DeleteWebhook" )
Variables ¶
var ( StatusResponse_Status_name = map[int32]string{ 0: "STATUS_UNKNOWN", 1: "STATUS_ACTIVE", 2: "STATUS_DISCONNECTED", 3: "STATUS_NOT_FOUND", } StatusResponse_Status_value = map[string]int32{ "STATUS_UNKNOWN": 0, "STATUS_ACTIVE": 1, "STATUS_DISCONNECTED": 2, "STATUS_NOT_FOUND": 3, } )
Enum value maps for StatusResponse_Status.
var ControllerService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "ControllerService", HandlerType: (*ControllerServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Status", Handler: _ControllerService_Status_Handler, }, { MethodName: "SendMessage", Handler: _ControllerService_SendMessage_Handler, }, { MethodName: "SendImageMessage", Handler: _ControllerService_SendImageMessage_Handler, }, { MethodName: "GetWebhook", Handler: _ControllerService_GetWebhook_Handler, }, { MethodName: "SaveWebhook", Handler: _ControllerService_SaveWebhook_Handler, }, { MethodName: "DeleteWebhook", Handler: _ControllerService_DeleteWebhook_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "RegisterDevice", Handler: _ControllerService_RegisterDevice_Handler, ServerStreams: true, }, { StreamName: "ReceiveMessage", Handler: _ControllerService_ReceiveMessage_Handler, ServerStreams: true, }, }, Metadata: "proto/wadoh.proto", }
ControllerService_ServiceDesc is the grpc.ServiceDesc for ControllerService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_proto_wadoh_proto protoreflect.FileDescriptor
Functions ¶
func RegisterControllerServiceServer ¶
func RegisterControllerServiceServer(s grpc.ServiceRegistrar, srv ControllerServiceServer)
Types ¶
type ControllerServiceClient ¶
type ControllerServiceClient interface {
Status(ctx context.Context, in *StatusRequest, opts ...grpc.CallOption) (*StatusResponse, error)
RegisterDevice(ctx context.Context, in *RegisterDeviceRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[RegisterDeviceResponse], error)
SendMessage(ctx context.Context, in *SendMessageRequest, opts ...grpc.CallOption) (*Empty, error)
SendImageMessage(ctx context.Context, in *SendImageMessageRequest, opts ...grpc.CallOption) (*SendImageMessageResponse, error)
ReceiveMessage(ctx context.Context, in *Empty, opts ...grpc.CallOption) (grpc.ServerStreamingClient[EventMessage], error)
GetWebhook(ctx context.Context, in *GetWebhookRequest, opts ...grpc.CallOption) (*GetWebhookResponse, error)
SaveWebhook(ctx context.Context, in *SaveWebhookRequest, opts ...grpc.CallOption) (*Empty, error)
DeleteWebhook(ctx context.Context, in *DeleteWebhookRequest, opts ...grpc.CallOption) (*Empty, error)
}
ControllerServiceClient is the client API for ControllerService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewControllerServiceClient ¶
func NewControllerServiceClient(cc grpc.ClientConnInterface) ControllerServiceClient
type ControllerServiceServer ¶
type ControllerServiceServer interface {
Status(context.Context, *StatusRequest) (*StatusResponse, error)
RegisterDevice(*RegisterDeviceRequest, grpc.ServerStreamingServer[RegisterDeviceResponse]) error
SendMessage(context.Context, *SendMessageRequest) (*Empty, error)
SendImageMessage(context.Context, *SendImageMessageRequest) (*SendImageMessageResponse, error)
ReceiveMessage(*Empty, grpc.ServerStreamingServer[EventMessage]) error
GetWebhook(context.Context, *GetWebhookRequest) (*GetWebhookResponse, error)
SaveWebhook(context.Context, *SaveWebhookRequest) (*Empty, error)
DeleteWebhook(context.Context, *DeleteWebhookRequest) (*Empty, error)
// contains filtered or unexported methods
}
ControllerServiceServer is the server API for ControllerService service. All implementations must embed UnimplementedControllerServiceServer for forward compatibility.
type ControllerService_ReceiveMessageClient ¶
type ControllerService_ReceiveMessageClient = grpc.ServerStreamingClient[EventMessage]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ControllerService_ReceiveMessageServer ¶
type ControllerService_ReceiveMessageServer = grpc.ServerStreamingServer[EventMessage]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ControllerService_RegisterDeviceClient ¶
type ControllerService_RegisterDeviceClient = grpc.ServerStreamingClient[RegisterDeviceResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type ControllerService_RegisterDeviceServer ¶
type ControllerService_RegisterDeviceServer = grpc.ServerStreamingServer[RegisterDeviceResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type DeleteWebhookRequest ¶
type DeleteWebhookRequest struct {
Jid string `protobuf:"bytes,1,opt,name=jid,proto3" json:"jid,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteWebhookRequest) Descriptor
deprecated
func (*DeleteWebhookRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteWebhookRequest.ProtoReflect.Descriptor instead.
func (*DeleteWebhookRequest) GetJid ¶
func (x *DeleteWebhookRequest) GetJid() string
func (*DeleteWebhookRequest) ProtoMessage ¶
func (*DeleteWebhookRequest) ProtoMessage()
func (*DeleteWebhookRequest) ProtoReflect ¶
func (x *DeleteWebhookRequest) ProtoReflect() protoreflect.Message
func (*DeleteWebhookRequest) Reset ¶
func (x *DeleteWebhookRequest) Reset()
func (*DeleteWebhookRequest) String ¶
func (x *DeleteWebhookRequest) String() string
type Empty ¶
type Empty struct {
// contains filtered or unexported fields
}
func (*Empty) Descriptor
deprecated
func (*Empty) ProtoMessage ¶
func (*Empty) ProtoMessage()
func (*Empty) ProtoReflect ¶
func (x *Empty) ProtoReflect() protoreflect.Message
type EventMessage ¶
type EventMessage struct {
Jid string `protobuf:"bytes,1,opt,name=jid,proto3" json:"jid,omitempty"`
From string `protobuf:"bytes,2,opt,name=from,proto3" json:"from,omitempty"`
Message string `protobuf:"bytes,3,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*EventMessage) Descriptor
deprecated
func (*EventMessage) Descriptor() ([]byte, []int)
Deprecated: Use EventMessage.ProtoReflect.Descriptor instead.
func (*EventMessage) GetFrom ¶
func (x *EventMessage) GetFrom() string
func (*EventMessage) GetJid ¶
func (x *EventMessage) GetJid() string
func (*EventMessage) GetMessage ¶
func (x *EventMessage) GetMessage() string
func (*EventMessage) ProtoMessage ¶
func (*EventMessage) ProtoMessage()
func (*EventMessage) ProtoReflect ¶
func (x *EventMessage) ProtoReflect() protoreflect.Message
func (*EventMessage) Reset ¶
func (x *EventMessage) Reset()
func (*EventMessage) String ¶
func (x *EventMessage) String() string
type GetWebhookRequest ¶
type GetWebhookRequest struct {
Jid string `protobuf:"bytes,1,opt,name=jid,proto3" json:"jid,omitempty"`
// contains filtered or unexported fields
}
func (*GetWebhookRequest) Descriptor
deprecated
func (*GetWebhookRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetWebhookRequest.ProtoReflect.Descriptor instead.
func (*GetWebhookRequest) GetJid ¶
func (x *GetWebhookRequest) GetJid() string
func (*GetWebhookRequest) ProtoMessage ¶
func (*GetWebhookRequest) ProtoMessage()
func (*GetWebhookRequest) ProtoReflect ¶
func (x *GetWebhookRequest) ProtoReflect() protoreflect.Message
func (*GetWebhookRequest) Reset ¶
func (x *GetWebhookRequest) Reset()
func (*GetWebhookRequest) String ¶
func (x *GetWebhookRequest) String() string
type GetWebhookResponse ¶
type GetWebhookResponse struct {
Url string `protobuf:"bytes,1,opt,name=url,proto3" json:"url,omitempty"`
Timestamp int64 `protobuf:"varint,2,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
// contains filtered or unexported fields
}
func (*GetWebhookResponse) Descriptor
deprecated
func (*GetWebhookResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetWebhookResponse.ProtoReflect.Descriptor instead.
func (*GetWebhookResponse) GetTimestamp ¶
func (x *GetWebhookResponse) GetTimestamp() int64
func (*GetWebhookResponse) GetUrl ¶
func (x *GetWebhookResponse) GetUrl() string
func (*GetWebhookResponse) ProtoMessage ¶
func (*GetWebhookResponse) ProtoMessage()
func (*GetWebhookResponse) ProtoReflect ¶
func (x *GetWebhookResponse) ProtoReflect() protoreflect.Message
func (*GetWebhookResponse) Reset ¶
func (x *GetWebhookResponse) Reset()
func (*GetWebhookResponse) String ¶
func (x *GetWebhookResponse) String() string
type RegisterDeviceRequest ¶
type RegisterDeviceRequest struct {
Phone string `protobuf:"bytes,1,opt,name=phone,proto3" json:"phone,omitempty"`
PushNotification bool `protobuf:"varint,2,opt,name=push_notification,json=pushNotification,proto3" json:"push_notification,omitempty"`
// contains filtered or unexported fields
}
func (*RegisterDeviceRequest) Descriptor
deprecated
func (*RegisterDeviceRequest) Descriptor() ([]byte, []int)
Deprecated: Use RegisterDeviceRequest.ProtoReflect.Descriptor instead.
func (*RegisterDeviceRequest) GetPhone ¶
func (x *RegisterDeviceRequest) GetPhone() string
func (*RegisterDeviceRequest) GetPushNotification ¶
func (x *RegisterDeviceRequest) GetPushNotification() bool
func (*RegisterDeviceRequest) ProtoMessage ¶
func (*RegisterDeviceRequest) ProtoMessage()
func (*RegisterDeviceRequest) ProtoReflect ¶
func (x *RegisterDeviceRequest) ProtoReflect() protoreflect.Message
func (*RegisterDeviceRequest) Reset ¶
func (x *RegisterDeviceRequest) Reset()
func (*RegisterDeviceRequest) String ¶
func (x *RegisterDeviceRequest) String() string
type RegisterDeviceResponse ¶
type RegisterDeviceResponse struct {
Qr *string `protobuf:"bytes,1,opt,name=qr,proto3,oneof" json:"qr,omitempty"`
PairCode *string `protobuf:"bytes,2,opt,name=pair_code,json=pairCode,proto3,oneof" json:"pair_code,omitempty"`
LoggedIn *bool `protobuf:"varint,3,opt,name=loggedIn,proto3,oneof" json:"loggedIn,omitempty"`
Jid *string `protobuf:"bytes,4,opt,name=jid,proto3,oneof" json:"jid,omitempty"`
// contains filtered or unexported fields
}
func (*RegisterDeviceResponse) Descriptor
deprecated
func (*RegisterDeviceResponse) Descriptor() ([]byte, []int)
Deprecated: Use RegisterDeviceResponse.ProtoReflect.Descriptor instead.
func (*RegisterDeviceResponse) GetJid ¶
func (x *RegisterDeviceResponse) GetJid() string
func (*RegisterDeviceResponse) GetLoggedIn ¶
func (x *RegisterDeviceResponse) GetLoggedIn() bool
func (*RegisterDeviceResponse) GetPairCode ¶
func (x *RegisterDeviceResponse) GetPairCode() string
func (*RegisterDeviceResponse) GetQr ¶
func (x *RegisterDeviceResponse) GetQr() string
func (*RegisterDeviceResponse) ProtoMessage ¶
func (*RegisterDeviceResponse) ProtoMessage()
func (*RegisterDeviceResponse) ProtoReflect ¶
func (x *RegisterDeviceResponse) ProtoReflect() protoreflect.Message
func (*RegisterDeviceResponse) Reset ¶
func (x *RegisterDeviceResponse) Reset()
func (*RegisterDeviceResponse) String ¶
func (x *RegisterDeviceResponse) String() string
type SaveWebhookRequest ¶
type SaveWebhookRequest struct {
Jid string `protobuf:"bytes,1,opt,name=jid,proto3" json:"jid,omitempty"`
Url string `protobuf:"bytes,2,opt,name=url,proto3" json:"url,omitempty"`
// contains filtered or unexported fields
}
func (*SaveWebhookRequest) Descriptor
deprecated
func (*SaveWebhookRequest) Descriptor() ([]byte, []int)
Deprecated: Use SaveWebhookRequest.ProtoReflect.Descriptor instead.
func (*SaveWebhookRequest) GetJid ¶
func (x *SaveWebhookRequest) GetJid() string
func (*SaveWebhookRequest) GetUrl ¶
func (x *SaveWebhookRequest) GetUrl() string
func (*SaveWebhookRequest) ProtoMessage ¶
func (*SaveWebhookRequest) ProtoMessage()
func (*SaveWebhookRequest) ProtoReflect ¶
func (x *SaveWebhookRequest) ProtoReflect() protoreflect.Message
func (*SaveWebhookRequest) Reset ¶
func (x *SaveWebhookRequest) Reset()
func (*SaveWebhookRequest) String ¶
func (x *SaveWebhookRequest) String() string
type SendImageMessageRequest ¶
type SendImageMessageRequest struct {
Jid string `protobuf:"bytes,1,opt,name=jid,proto3" json:"jid,omitempty"`
Phone string `protobuf:"bytes,2,opt,name=phone,proto3" json:"phone,omitempty"`
Image []byte `protobuf:"bytes,3,opt,name=image,proto3" json:"image,omitempty"`
Caption string `protobuf:"bytes,4,opt,name=caption,proto3" json:"caption,omitempty"`
// contains filtered or unexported fields
}
func (*SendImageMessageRequest) Descriptor
deprecated
func (*SendImageMessageRequest) Descriptor() ([]byte, []int)
Deprecated: Use SendImageMessageRequest.ProtoReflect.Descriptor instead.
func (*SendImageMessageRequest) GetCaption ¶
func (x *SendImageMessageRequest) GetCaption() string
func (*SendImageMessageRequest) GetImage ¶
func (x *SendImageMessageRequest) GetImage() []byte
func (*SendImageMessageRequest) GetJid ¶
func (x *SendImageMessageRequest) GetJid() string
func (*SendImageMessageRequest) GetPhone ¶
func (x *SendImageMessageRequest) GetPhone() string
func (*SendImageMessageRequest) ProtoMessage ¶
func (*SendImageMessageRequest) ProtoMessage()
func (*SendImageMessageRequest) ProtoReflect ¶
func (x *SendImageMessageRequest) ProtoReflect() protoreflect.Message
func (*SendImageMessageRequest) Reset ¶
func (x *SendImageMessageRequest) Reset()
func (*SendImageMessageRequest) String ¶
func (x *SendImageMessageRequest) String() string
type SendImageMessageResponse ¶
type SendImageMessageResponse struct {
// contains filtered or unexported fields
}
func (*SendImageMessageResponse) Descriptor
deprecated
func (*SendImageMessageResponse) Descriptor() ([]byte, []int)
Deprecated: Use SendImageMessageResponse.ProtoReflect.Descriptor instead.
func (*SendImageMessageResponse) ProtoMessage ¶
func (*SendImageMessageResponse) ProtoMessage()
func (*SendImageMessageResponse) ProtoReflect ¶
func (x *SendImageMessageResponse) ProtoReflect() protoreflect.Message
func (*SendImageMessageResponse) Reset ¶
func (x *SendImageMessageResponse) Reset()
func (*SendImageMessageResponse) String ¶
func (x *SendImageMessageResponse) String() string
type SendMessageRequest ¶
type SendMessageRequest struct {
Jid string `protobuf:"bytes,1,opt,name=jid,proto3" json:"jid,omitempty"`
Phone string `protobuf:"bytes,2,opt,name=phone,proto3" json:"phone,omitempty"`
Body string `protobuf:"bytes,3,opt,name=body,proto3" json:"body,omitempty"`
// contains filtered or unexported fields
}
func (*SendMessageRequest) Descriptor
deprecated
func (*SendMessageRequest) Descriptor() ([]byte, []int)
Deprecated: Use SendMessageRequest.ProtoReflect.Descriptor instead.
func (*SendMessageRequest) GetBody ¶
func (x *SendMessageRequest) GetBody() string
func (*SendMessageRequest) GetJid ¶
func (x *SendMessageRequest) GetJid() string
func (*SendMessageRequest) GetPhone ¶
func (x *SendMessageRequest) GetPhone() string
func (*SendMessageRequest) ProtoMessage ¶
func (*SendMessageRequest) ProtoMessage()
func (*SendMessageRequest) ProtoReflect ¶
func (x *SendMessageRequest) ProtoReflect() protoreflect.Message
func (*SendMessageRequest) Reset ¶
func (x *SendMessageRequest) Reset()
func (*SendMessageRequest) String ¶
func (x *SendMessageRequest) String() string
type StatusRequest ¶
type StatusRequest struct {
Jid string `protobuf:"bytes,1,opt,name=jid,proto3" json:"jid,omitempty"`
// contains filtered or unexported fields
}
func (*StatusRequest) Descriptor
deprecated
func (*StatusRequest) Descriptor() ([]byte, []int)
Deprecated: Use StatusRequest.ProtoReflect.Descriptor instead.
func (*StatusRequest) GetJid ¶
func (x *StatusRequest) GetJid() string
func (*StatusRequest) ProtoMessage ¶
func (*StatusRequest) ProtoMessage()
func (*StatusRequest) ProtoReflect ¶
func (x *StatusRequest) ProtoReflect() protoreflect.Message
func (*StatusRequest) Reset ¶
func (x *StatusRequest) Reset()
func (*StatusRequest) String ¶
func (x *StatusRequest) String() string
type StatusResponse ¶
type StatusResponse struct {
Status StatusResponse_Status `protobuf:"varint,1,opt,name=status,proto3,enum=StatusResponse_Status" json:"status,omitempty"`
// contains filtered or unexported fields
}
func (*StatusResponse) Descriptor
deprecated
func (*StatusResponse) Descriptor() ([]byte, []int)
Deprecated: Use StatusResponse.ProtoReflect.Descriptor instead.
func (*StatusResponse) GetStatus ¶
func (x *StatusResponse) GetStatus() StatusResponse_Status
func (*StatusResponse) ProtoMessage ¶
func (*StatusResponse) ProtoMessage()
func (*StatusResponse) ProtoReflect ¶
func (x *StatusResponse) ProtoReflect() protoreflect.Message
func (*StatusResponse) Reset ¶
func (x *StatusResponse) Reset()
func (*StatusResponse) String ¶
func (x *StatusResponse) String() string
type StatusResponse_Status ¶
type StatusResponse_Status int32
const ( StatusResponse_STATUS_UNKNOWN StatusResponse_Status = 0 StatusResponse_STATUS_ACTIVE StatusResponse_Status = 1 StatusResponse_STATUS_DISCONNECTED StatusResponse_Status = 2 StatusResponse_STATUS_NOT_FOUND StatusResponse_Status = 3 )
func (StatusResponse_Status) Descriptor ¶
func (StatusResponse_Status) Descriptor() protoreflect.EnumDescriptor
func (StatusResponse_Status) Enum ¶
func (x StatusResponse_Status) Enum() *StatusResponse_Status
func (StatusResponse_Status) EnumDescriptor
deprecated
func (StatusResponse_Status) EnumDescriptor() ([]byte, []int)
Deprecated: Use StatusResponse_Status.Descriptor instead.
func (StatusResponse_Status) Number ¶
func (x StatusResponse_Status) Number() protoreflect.EnumNumber
func (StatusResponse_Status) String ¶
func (x StatusResponse_Status) String() string
func (StatusResponse_Status) Type ¶
func (StatusResponse_Status) Type() protoreflect.EnumType
type UnimplementedControllerServiceServer ¶
type UnimplementedControllerServiceServer struct{}
UnimplementedControllerServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedControllerServiceServer) DeleteWebhook ¶
func (UnimplementedControllerServiceServer) DeleteWebhook(context.Context, *DeleteWebhookRequest) (*Empty, error)
func (UnimplementedControllerServiceServer) GetWebhook ¶
func (UnimplementedControllerServiceServer) GetWebhook(context.Context, *GetWebhookRequest) (*GetWebhookResponse, error)
func (UnimplementedControllerServiceServer) ReceiveMessage ¶
func (UnimplementedControllerServiceServer) ReceiveMessage(*Empty, grpc.ServerStreamingServer[EventMessage]) error
func (UnimplementedControllerServiceServer) RegisterDevice ¶
func (UnimplementedControllerServiceServer) RegisterDevice(*RegisterDeviceRequest, grpc.ServerStreamingServer[RegisterDeviceResponse]) error
func (UnimplementedControllerServiceServer) SaveWebhook ¶
func (UnimplementedControllerServiceServer) SaveWebhook(context.Context, *SaveWebhookRequest) (*Empty, error)
func (UnimplementedControllerServiceServer) SendImageMessage ¶
func (UnimplementedControllerServiceServer) SendImageMessage(context.Context, *SendImageMessageRequest) (*SendImageMessageResponse, error)
func (UnimplementedControllerServiceServer) SendMessage ¶
func (UnimplementedControllerServiceServer) SendMessage(context.Context, *SendMessageRequest) (*Empty, error)
func (UnimplementedControllerServiceServer) Status ¶
func (UnimplementedControllerServiceServer) Status(context.Context, *StatusRequest) (*StatusResponse, error)
type UnsafeControllerServiceServer ¶
type UnsafeControllerServiceServer interface {
// contains filtered or unexported methods
}
UnsafeControllerServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ControllerServiceServer will result in compilation errors.